@@ -94,6 +94,24 @@ class FlowRecord:
         'pkt_dst_aws_service',
         'flow_direction',
         'traffic_path',
+        'resource_type',
+        'tgw_id',
+        'tgw_attachment_id',
+        'tgw_src_vpc_account_id',
+        'tgw_dst_vpc_account_id',
+        'tgw_src_vpc_id',
+        'tgw_dst_vpc_id',
+        'tgw_src_subnet_id',
+        'tgw_dst_subnet_id',
+        'tgw_src_eni',
+        'tgw_dst_eni',
+        'tgw_src_az_id',
+        'tgw_dst_az_id',
+        'tgw_pair_attachment_id',
+        'packets_lost_no_route',
+        'packets_lost_blackhole',
+        'packets_lost_mtu_exceeded',
+        'packets_lost_ttl_expired',
     ]
 
     def __init__(self, event_data, EPOCH_32_MAX=2147483647):
@@ -144,6 +162,24 @@ class FlowRecord:
             ('pkt_dst_aws_service', str),
             ('flow_direction', str),
             ('traffic_path', int),
+            ('resource_type', str),
+            ('tgw_id', str),
+            ('tgw_attachment_id', str),
+            ('tgw_src_vpc_account_id', str),
+            ('tgw_dst_vpc_account_id', str),
+            ('tgw_src_vpc_id', str),
+            ('tgw_dst_vpc_id', str),
+            ('tgw_src_subnet_id', str),
+            ('tgw_dst_subnet_id', str),
+            ('tgw_src_eni', str),
+            ('tgw_dst_eni', str),
+            ('tgw_src_az_id', str),
+            ('tgw_dst_az_id', str),
+            ('tgw_pair_attachment_id', str),
+            ('packets_lost_no_route', int),
+            ('packets_lost_blackhole', int),
+            ('packets_lost_mtu_exceeded', int),
+            ('packets_lost_ttl_expired', int),
         ):
             value = event_data.get(key, '-')
             if value == '-' or value == 'None' or value is None:
@@ -213,6 +249,7 @@ class BaseReader:
         start_time=None,
         end_time=None,
         boto_client=None,
+        raise_on_error=False
     ):
         self.region_name = region_name
         if boto_client is not None:
@@ -229,6 +266,9 @@ class BaseReader:
         self.bytes_processed = 0
         self.iterator = self._reader()
 
+        self.skipped_records = 0
+        self.raise_on_error = raise_on_error
+
     def __iter__(self):
         return self
 
@@ -279,6 +319,7 @@ class FlowLogsReader(BaseReader):
 
         self.start_ms = timegm(self.start_time.utctimetuple()) * 1000
         self.end_ms = timegm(self.end_time.utctimetuple()) * 1000
+        self.skipped_records = 0
 
     def _get_fields(self, region_name, log_group_name, ec2_client=None):
         if ec2_client is None:
@@ -351,10 +392,21 @@ class FlowLogsReader(BaseReader):
                 func = lambda x: list(self._read_streams(x))
                 for events in executor.map(func, all_streams):
                     for event in events:
-                        yield FlowRecord.from_cwl_event(event, self.fields)
+                        try: 
+                            yield FlowRecord.from_cwl_event(event, self.fields)
+                        except Exception:
+                            self.skipped_records += 1
+                            if self.raise_on_error:
+                                raise  
         else:
             for event in self._read_streams():
-                yield FlowRecord.from_cwl_event(event, self.fields)
+                try: 
+                    yield FlowRecord.from_cwl_event(event, self.fields)
+                except Exception:
+                    self.skipped_records += 1
+                    if self.raise_on_error:
+                        raise
+
 
 
 class S3FlowLogsReader(BaseReader):
@@ -490,4 +542,10 @@ class S3FlowLogsReader(BaseReader):
 
     def _reader(self):
         for event_data in self._read_streams():
-            yield FlowRecord(event_data)
+            try: 
+                yield FlowRecord(event_data)
+            except Exception:
+                self.skipped_records += 1
+                if self.raise_on_error:
+                    raise
+
